@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of a MIDI file
 
-our $VERSION = '0.01';
+our $VERSION = '0.0101';
 
 use Moo;
 use strictures 2;
@@ -391,13 +391,13 @@ MIDI::Ngram - Find the top repeated note phrases of a MIDI file
 
 =head1 VERSION
 
-version 0.01
+version 0.0101
 
 =head1 SYNOPSIS
 
   use MIDI::Ngram;
   my $mng = MIDI::Ngram->new(
-    file    => 't/twinkle_twinkle.mid',
+    file    => 'eg/twinkle_twinkle.mid',
     size    => 3,
     verbose => 1,
   );
